diff mbox series

ui/cocoa: Make sure app is not starting in the background

Message ID 20190215005614.3AD927456C9@zero.eik.bme.hu
State New
Headers show
Series ui/cocoa: Make sure app is not starting in the background | expand

Commit Message

BALATON Zoltan Feb. 15, 2019, 12:14 a.m. UTC
Activate app to make sure the window is brought to front e.g. when
started from a terminal window.

Signed-off-by: BALATON Zoltan <balaton@eik.bme.hu>
---
This is on top of Peter's patches.

 ui/cocoa.m | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)
diff mbox series

Patch

diff --git a/ui/cocoa.m b/ui/cocoa.m
index 201a294ed4..4727f9c392 100644
--- a/ui/cocoa.m
+++ b/ui/cocoa.m
@@ -1746,7 +1746,8 @@  int main (int argc, const char * argv[]) {
     QemuCocoaAppController *appController = [[QemuCocoaAppController alloc] init];
     [NSApp setDelegate:appController];
 
-    // Start the main event loop
+    // Activate app and start the main event loop
+    [NSApp activateIgnoringOtherApps:YES];
     COCOA_DEBUG("Main thread: entering OSX run loop\n");
     [NSApp run];
     COCOA_DEBUG("Main thread: left OSX run loop, exiting\n");